import {IBuildTaskOption} from '../@types';
import {IBuildResult} from '../@types';
// @ts-ignore
const child_process = require('child_process');
// @ts-ignore
const fs = require('fs');
// @ts-ignore
const pathTool = require("path");
interface IOptions {
    isWxUm: boolean
    umId: string
    debug: boolean
    useOpenid: boolean
}

interface IOptions2 {
    platform: string
}


const PACKAGE_NAME = 'build-plugin-wx_um_3d';

interface ITaskOptions extends IBuildTaskOption {
    packages: {
        'build-plugin-wx_um_3d': IOptions;
        'build-plugin-exportconfig': IOptions2;
    };
}

function log(...arg: any[]) {
    return console.log(`[${PACKAGE_NAME}] `, ...arg);
}

/**
 * 创建目录
 * @param path
 */
function mkDir(path: string) {
    if (fs.existsSync(path)) {
        var tempstats = fs.statSync(path);
        if (!tempstats.isDirectory()) {
            fs.unlinkSync(path);
            fs.mkdirSync(path);
        }
    } else {
        fs.mkdirSync(path);
    }
}

let allAssets = [];

export const throwError = true;

export async function load() {
    allAssets = await Editor.Message.request('asset-db', 'query-assets');
}

export async function onBeforeBuild(options: ITaskOptions) {
}

export async function onBeforeCompressSettings(options: ITaskOptions, result: IBuildResult) {

}

export async function onAfterCompressSettings(options: ITaskOptions, result: IBuildResult) {

}

export async function onAfterBuild(options: ITaskOptions, result: IBuildResult) {
    if (!options.packages["build-plugin-wx_um_3d"].isWxUm) {
        return;
    }
    let dir = result.paths.dir;
    if(options.platform == "vivo-mini-game"){
        dir = pathTool.join(dir,"src");
    }
    let gameJsPath = pathTool.join(dir, "game.js");
    let path = pathTool.join(__dirname, "utils");
    let requirePath = "import uma from \"./utils";
    switch (options.platform) {
        case "wechatgame":
            if (options.packages["build-plugin-exportconfig"] && options.packages["build-plugin-exportconfig"].platform == "qq") {
                path = pathTool.join(path, "umtrack-qq-game");
                requirePath = "uma = require(\"/utils/umtrack/lib/uma.min.js\");\n" +
                    "qq.uma = uma;\n"
                break;
            }
            if (options.packages["build-plugin-exportconfig"] && options.packages["build-plugin-exportconfig"].platform == "kuaishou") {
                path = pathTool.join(path, "umtrack-kuaishou");
                requirePath = requirePath + "/umtrack/lib/uma.min.js\"";
                break;
            }
            path = pathTool.join(path, "umtrack-wx-game");
            let require = requirePath;
            requirePath = require + "/umtrack/lib/index.js\"";
            break;
        case "oppo-mini-game":
            gameJsPath = pathTool.join(dir, "main.js");
        case "huawei-quick-game":
        case "vivo-mini-game":
        case "xiaomi-quick-game":
            path = pathTool.join(path, "umtrack-quickgame");
            requirePath = "require('./utils/umtrack/lib/uma.min.js')";
            break;
        case "bytedance-mini-game":
            path = pathTool.join(path, "umtrack-tt-game");
            requirePath = requirePath + "/umtrack/lib/uma.min.js\"";
            break;
        default:
            return;
    }
    let targetPath = pathTool.join(dir, "utils");
    mkDir(targetPath);
    targetPath = pathTool.join(targetPath, "umtrack");
    mkDir(targetPath);
    // @ts-ignore
    let cmdStr = process.platform == "darwin" ? `cp -a -f ${path}/* ${targetPath}`
        : 'echo d|xcopy ' + path + ' ' + targetPath + " /s/y";
    log("copy cmd:" + cmdStr)
    child_process.spawn(process.platform == "darwin" ? "/bin/bash" : "cmd.exe", (process.platform == "darwin" ? ['-c'] : ['/s', '/c']).concat([  cmdStr]));
    let content = fs.readFileSync(gameJsPath, 'utf8').toString();
    content = `${requirePath};
uma.init({
  appKey: '${options.packages["build-plugin-wx_um_3d"].umId}',
  useOpenid: ${options.packages["build-plugin-wx_um_3d"].useOpenid}, // default true
  autoGetOpenid: ${options.packages["build-plugin-wx_um_3d"].useOpenid},
  debug: ${options.packages["build-plugin-wx_um_3d"].debug}
});\n` + content;
    fs.writeFileSync(gameJsPath, content);

}

export function unload() {
}
